﻿using Exam.Application.Interface.Sourcewares;
using Exam.Infrastructure.Data.Entity;
using Exam.Share;
using Exam.Share.Dtos.Sourcewares;
using Hotline.Application.Exam.Constants;
using Hotline.Share.Requests.Sourceware;
using Microsoft.AspNetCore.Mvc;

namespace Hotline.Api.Controllers.Exam
{
    public class SourcewaresController : BaseController
    {
        private ISourcewareService _sourcewareService;

        public SourcewaresController(ISourcewareService sourcewareService)
        {
            _sourcewareService = sourcewareService;
        }

        /// <summary>
        /// 新增课件
        /// </summary>
        /// <param name="sourcewareDto"></param>
        /// <returns></returns>
        [HttpPost(SourcewareRouteApi.Add)]
        public async Task Add([FromBody] SourcewareDto sourcewareDto)
        {
            await _sourcewareService.AddAsync(sourcewareDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 修改课件
        /// </summary>
        /// <param name="sourcewareDto"></param>
        /// <returns></returns>
        [HttpPut(SourcewareRouteApi.Update)]
        public async Task Update([FromBody] SourcewareDto sourcewareDto)
        {
            await _sourcewareService.UpdateAsync(sourcewareDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 删除课件
        /// </summary>
        /// <param name="entityQueryRequest"></param>
        /// <returns></returns>
        [HttpDelete(SourcewareRouteApi.Delete)]
        public async Task Delete([FromBody] EntityQueryRequest entityQueryRequest)
        {
            await _sourcewareService.DeleteAsync(entityQueryRequest, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 获取课件分页列表
        /// </summary>
        /// <param name="sourcewarePagedRequest"></param>
        /// <returns></returns>
        [HttpPost(SourcewareRouteApi.GetPagedList)]
        public async Task<SourcewarePageViewResponse> GetPagedList([FromBody] SourcewarePagedRequest sourcewarePagedRequest)
        {
            var sourcewarePageViewResponse = await _sourcewareService.GetPagedListAsync(sourcewarePagedRequest);

            return sourcewarePageViewResponse as SourcewarePageViewResponse; 
        }
    }
}
