using Exam.Application;
using Exam.Application.Interface.Sourcewares;
using Exam.Application.QueryExtensions.Sourcewares;
using Exam.Infrastructure.Data.Entity;
using Exam.Insfrastructure.Service.Service;
using Exam.Share;
using Exam.Share.Dtos.Sourcewares;
using Exam.Sourcewares;
using Hotline.Repository.SqlSugar;
using Hotline.Repository.SqlSugar.Exam.Interfaces.Sourcewares;
using Hotline.Share.Requests.Sourceware;
using Mapster;
using System.ComponentModel;
using XF.Domain.Dependency;

namespace Exam.Application.Service.Sourcewares
{
    /// <summary>
    /// 课件服务
    /// </summary>
    [Description("课件服务")]
    public class SourcewareService : ApiService<Sourceware, SourcewareDto,HotlineDbContext>,ISourcewareService, IScopeDependency
    {
        private readonly ISourcewareRepository _repository;
        public SourcewareService(ISourcewareRepository repository) : base(repository)
        {
            _repository = repository;
        }

        public async Task<SourcewareDto> GetAsync(EntityQueryRequest entityQueryRequest)
        {
            var entity = await _repository.GetAsync(entityQueryRequest.Id);

            return entity.Adapt<SourcewareDto>();
        }

        public async Task<(int, List<SourcewareViewResponse>)> GetListAsync(SourcewarePagedRequest queryRequest)
        {
            var query = _repository.Queryable();

            var result = await query.Select(m => new SourcewareViewResponse { 
                				Name = m.Name,
								CategoryId = m.CategoryId,
								AttachmentId = m.AttachmentId,
								Id = m.Id,
				            }).ToListAsync();

            var total = await query.CountAsync();

            return (total,result);
        }

        public async Task<PageViewResponse<SourcewareViewResponse>> GetPagedListAsync(SourcewarePagedRequest queryRequest)
        {
            var expression = queryRequest.GetExpression();
            var sourcewareTable = _repository.Queryable().Where(expression);

            var queryable = sourcewareTable.Select((m) => new SourcewareViewResponse
            {
                				Name = m.Name,
								CategoryId = m.CategoryId,
								AttachmentId = m.AttachmentId,
								Id = m.Id,
				            });

            var list = await queryable.ToPageListAsync(queryRequest.PageIndex, queryRequest.PageSize);
            var total = await queryable.CountAsync();

            var result = new PageViewResponse<SourcewareViewResponse>
            {
                Items = list,
                Pagination = new Pagination(queryRequest.PageIndex, queryRequest.PageSize, total)
            };

            return result;
        }
    }
}


